from collections.abc import AsyncGenerator
from contextlib import asynccontextmanager

import httpx

from oxylabs_ai_studio.logger import get_logger

logger = get_logger(__file__)

API_URL = "https://api-aistudio.oxylabs.io/v1"


class OxyStudioAIClient:
    """Main client for interacting with the Oxy Studio AI API."""

    def __init__(self, api_key: str, timeout: float = 30.0):
        if not api_key:
            raise ValueError("API key is required")

        self.api_key = api_key
        self.base_url = API_URL
        self.timeout = timeout
        # Initialize HTTP client with proper headers
        self.client = httpx.Client(
            base_url=self.base_url,
            headers={
                "x-api-key": api_key,
                "Content-Type": "application/json",
                "User-Agent": "python-sdk",
            },
            timeout=timeout,
        )

    @asynccontextmanager
    async def async_client(self) -> AsyncGenerator[httpx.AsyncClient, None]:
        """Async context manager for async client."""
        async_client = httpx.AsyncClient(
            base_url=self.base_url,
            headers={
                "x-api-key": self.api_key,
                "Content-Type": "application/json",
                "User-Agent": "python-sdk",
            },
            timeout=self.timeout,
        )
        try:
            yield async_client
        finally:
            await async_client.aclose()
